.. documentation master file

.. image:: ../images/sf-logo-web_icon.png
   :scale: 15 %
   :align: center

StaticFrame
=========================================

Immutable data structures for one- and two-dimensional calculations with self-aligning, labelled axes.

- Code: https://github.com/InvestmentSystems/static-frame
- Packages: https://pypi.org/project/static-frame
- Benchmarks: https://investmentsystems.github.io/static-frame-benchmark


.. toctree::
   :maxdepth: 3
   :numbered:
   :caption: Quick Start

   readme
   license


.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Introduction

   intro
   new
   contributing

.. toctree::
   :maxdepth: 1
   :caption: Articles

   articles/upgrade
   articles/aiii


.. toctree::
   :maxdepth: 1
   :caption: API Overview

   api_overview/series
   api_overview/series_he
   api_overview/frame
   api_overview/frame_go
   api_overview/frame_he
   api_overview/bus
   api_overview/batch
   api_overview/yarn
   api_overview/quilt
   api_overview/index
   api_overview/index_go
   api_overview/index_hierarchy
   api_overview/index_hierarchy_go
   api_overview/index_year
   api_overview/index_year_go
   api_overview/index_year_month
   api_overview/index_year_month_go
   api_overview/index_date
   api_overview/index_date_go
   api_overview/index_minute
   api_overview/index_minute_go
   api_overview/index_hour
   api_overview/index_hour_go
   api_overview/index_second
   api_overview/index_second_go
   api_overview/index_millisecond
   api_overview/index_millisecond_go
   api_overview/index_microsecond
   api_overview/index_microsecond_go
   api_overview/index_nanosecond
   api_overview/index_nanosecond_go
   api_overview/display_config
   api_overview/store_config
   api_overview/store_filter

.. toctree::
   :maxdepth: 1
   :caption: API Detail

   api_detail/series
   api_detail/series_he
   api_detail/frame
   api_detail/frame_go
   api_detail/frame_he
   api_detail/bus
   api_detail/batch
   api_detail/yarn
   api_detail/quilt
   api_detail/index
   api_detail/index_go
   api_detail/index_hierarchy
   api_detail/index_hierarchy_go
   api_detail/index_year
   api_detail/index_year_go
   api_detail/index_year_month
   api_detail/index_year_month_go
   api_detail/index_date
   api_detail/index_date_go
   api_detail/index_minute
   api_detail/index_minute_go
   api_detail/index_hour
   api_detail/index_hour_go
   api_detail/index_second
   api_detail/index_second_go
   api_detail/index_millisecond
   api_detail/index_millisecond_go
   api_detail/index_microsecond
   api_detail/index_microsecond_go
   api_detail/index_nanosecond
   api_detail/index_nanosecond_go
   api_detail/display_config
   api_detail/store_config
   api_detail/store_filter

:ref:`genindex`
